@@ -32,16 +32,16 @@
 
 // Include files for KDE
 
-#include <klocale.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
 #include <kprocess.h>
 #include <kcolorbutton.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 // Local includes
 
@@ -62,7 +62,7 @@ ResizeImagesDialog::ResizeImagesDialog( KURL::List urlList, KIPI::Interface* int
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Batch resize images"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to batch-resize images\n"
                                                      "This plugin uses the \"convert\" program from \"ImageMagick\" package."),
                                            "(c) 2003-2007, Gilles Caulier");
@@ -124,7 +124,7 @@ ResizeImagesDialog::~ResizeImagesDialog()
 
 void ResizeImagesDialog::slotHelp( void )
 {
-    KApplication::kApplication()->invokeHelp("resizeimages", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("resizeimages", "kipi-plugins");
 }
 
 void ResizeImagesDialog::slotOptionsClicked(void)
@@ -216,7 +216,7 @@ void ResizeImagesDialog::readSettings(void)
 
     TQColor *ColorWhite = new TQColor( 255, 255, 255 );
     TQColor *ColorBlack = new TQColor( 0, 0, 0 );
-    m_config = new KConfig("kipirc");
+    m_config = new TDEConfig("kipirc");
     m_config->setGroup("ResizeImages Settings");
 
     m_Type->setCurrentItem(m_config->readNumEntry("ResiseType", 3)); // Prepare to print per default.
@@ -262,7 +262,7 @@ void ResizeImagesDialog::saveSettings(void)
 {
     // Write all settings in configuration file.
 
-    m_config = new KConfig("kipirc");
+    m_config = new TDEConfig("kipirc");
     m_config->setGroup("ResizeImages Settings");
     m_config->writeEntry("ResiseType", m_Type->currentItem());
     m_config->writeEntry("Size", m_size);
@@ -294,7 +294,7 @@ void ResizeImagesDialog::saveSettings(void)
     delete m_config;
 }
 
-TQString ResizeImagesDialog::makeProcess(KProcess* proc, BatchProcessImagesItem *item,
+TQString ResizeImagesDialog::makeProcess(TDEProcess* proc, BatchProcessImagesItem *item,
                                         const TQString& albumDest, bool )
 {
     TQImage img;
