@@ -11,9 +11,7 @@
  *                                                                         *
  ***************************************************************************/
 
-extern "C" {
 #include <glib-object.h> //g_type_init
-}
 
 #include "ipodexportdialog.h"
 #include "plugin_ipodexport.h"
@@ -49,7 +47,7 @@ void Plugin_iPodExport::setup( TQWidget* widget )
     KIPI::Plugin::setup( widget );
 
     // this is our action shown in the menubar/toolbar of the mainwindow
-    m_actionImageUpload = new TDEAction( i18n( "Export to iPod..." ), "multimedia-player", 0, this,
+    m_actionImageUpload = new TDEAction( i18n( "Export to iPod..." ), "multimedia-player-unmounted", 0, this,
                                       TQT_SLOT( slotImageUpload() ), actionCollection(), "connectipod");
 
     addAction( m_actionImageUpload );
