@@ -50,7 +50,7 @@ Plugin_KameraKlient::~Plugin_KameraKlient() {
 void Plugin_KameraKlient::setup(TQWidget* widget) {
 	KIPI::Plugin::setup(widget);
 	mKameraKlientAction = new TDEAction(i18n("Digital Camera"),
-							"camera_unmount",
+							"camera-unmounted",
 							TDEShortcut(),
 							this,
 							TQT_SLOT(slotActivate()),
