@@ -32,7 +32,7 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdialog.h>
 #include <klineedit.h>
 #include <kactivelabel.h>
