@@ -25,12 +25,12 @@
 
 #include <libkipi/plugin.h>
 
-class KAction;
+class TDEAction;
 
 class Plugin_PrintWizard : public KIPI::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
@@ -38,7 +38,7 @@ public:
                      const char* name,
                      const TQStringList &args);
     ~Plugin_PrintWizard();
-    virtual KIPI::Category category( KAction* action ) const;
+    virtual KIPI::Category category( TDEAction* action ) const;
     virtual void setup( TQWidget* widget );
 
 public slots:
@@ -46,7 +46,7 @@ public slots:
     void slotActivate();
 
 private:
-    KAction         *m_printAction;
+    TDEAction         *m_printAction;
     KIPI::Interface *m_interface;
 };
 
