@@ -49,14 +49,14 @@ extern "C"
 // KDE includes.
 
 #include <kcursor.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <kio/renamedlg.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
+#include <tdeio/renamedlg.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 
@@ -115,7 +115,7 @@ SingleDialog::SingleDialog(const TQString& file, TQWidget */*parent*/)
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("RAW Image Converter"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to convert a Raw image"),
                                            "(c) 2003-2005, Renchi Raju\n"
                                            "(c) 2006-2008, Gilles Caulier");
@@ -196,7 +196,7 @@ void SingleDialog::slotDefault()
 
 void SingleDialog::readSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
     m_decodingSettingsBox->setWhiteBalance((KDcrawIface::RawDecodingSettings::WhiteBalance)
@@ -242,7 +242,7 @@ void SingleDialog::readSettings()
 
 void SingleDialog::saveSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("RawConverter Settings");
 
     config.writeEntry("White Balance", m_decodingSettingsBox->whiteBalance());
@@ -276,7 +276,7 @@ void SingleDialog::saveSettings()
 
 void SingleDialog::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("rawconverter", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("rawconverter", "kipi-plugins");
 }
 
 // 'Preview' dialog button.
@@ -433,19 +433,19 @@ void SingleDialog::processed(const TQString&, const TQString& tmpFile)
         struct stat statBuf;
         if (::stat(TQFile::encodeName(destFile), &statBuf) == 0) 
         {
-            KIO::RenameDlg dlg(this, i18n("Save Raw Image converted from '%1' as").arg(fi.fileName()),
+            TDEIO::RenameDlg dlg(this, i18n("Save Raw Image converted from '%1' as").arg(fi.fileName()),
                                tmpFile, destFile,
-                               KIO::RenameDlg_Mode(KIO::M_SINGLE | KIO::M_OVERWRITE | KIO::M_SKIP));
+                               TDEIO::RenameDlg_Mode(TDEIO::M_SINGLE | TDEIO::M_OVERWRITE | TDEIO::M_SKIP));
 
             switch (dlg.exec())
             {
-                case KIO::R_CANCEL:
-                case KIO::R_SKIP:
+                case TDEIO::R_CANCEL:
+                case TDEIO::R_SKIP:
                 {
                     destFile = TQString();
                     break;
                 }
-                case KIO::R_RENAME:
+                case TDEIO::R_RENAME:
                 {
                     destFile = dlg.newDestURL().path();
                     break;
