@@ -342,7 +342,7 @@ void SendImages::makeCommentsFile(void)
             //Tags from the database
             if (m_interface->hasFeature(KIPI::HostSupportsTags))
             {
-                TQMap <TQString, TQVariant> attribs=info.attributes();
+                TQStringVariantMap attribs=info.attributes();
                 if (attribs["tags"].asStringList().count() > 0)
                 {
                     ImageCommentsText += i18n("Tags: %2\n").arg(attribs["tags"].asStringList().join(","));
